pub unsafe extern "C" fn nvd_stringify_error(
err: NvdError,
) -> *mut NvdDynamicStringExpand description
@brief Transforms an error code into a string representation, that can be used to print errors to the console. @returns A @ref NvdDynamicString containing the error as a string, or NULL in case of failure or invalid parameter. @ingroup Error @note Pre v0.10 code may not work with this function due to different return types.