NvdDynamicString

Type Alias NvdDynamicString 

pub type NvdDynamicString = _NvdDynamicString;
@brief A string type that can be resized, manipulated, converted and read from.

NvdDynamicString is a recent addition to the library that allows various kinds of strings across various operating systems to be abstracted and represented by a single type. Whereas const char* is widely used throughout the library, an NvdDynamicString is useful when strings are returned - Simple character literals cannot be returned since they are allocated on the stack. It is also simple to use and convert from and to char buffers, making it compatible with almost all existing APIs. @note Do not pass this to any parameters that require a char* without explicit conversion (See nvd_string_to_cstr()). @note Internally, this dynamic string maintains a capacity variable, that may allocate more memory than needed to store the string. This is done to avoid multiple allocations. @since v0.10.0 @ingroup String

Aliased Type

pub struct NvdDynamicString { /* private fields */ }