NvdFileDialog

Type Alias NvdFileDialog 

pub type NvdFileDialog = _NvdFileDialog;
@brief An opaque file dialog type, representing either a file dialog that can be used to open a file or save a file, and since v0.9.0, opening a directory instead. @since v0.1.0 @ingroup FileDialog

Aliased Type

pub struct NvdFileDialog { /* private fields */ }