NvdQuestionButton

Type Alias NvdQuestionButton 

pub type NvdQuestionButton = c_uint;
@brief Enumerator containing the possible arguments for nvd_dialog_question_new(). @details Each field describes the possible answers that will be included in a new @ref NvdQuestionDialog. More specifically:

  • NVD_YES_NO will have the dialog include only two buttons, yes and no (May differ per locale and system, but always affirmative and negative).
  • NVD_YES_NO_CANCEL is the same but also includes a cancel button. Sometimes this is ignored depending on the system.
  • NVD_YES_CANCEL is useful when you want to change the affirmative button’s text but want to use cancel for the negative. @since v0.1.0 @sa nvd_dialog_question_new