pub unsafe extern "C" fn nvd_string_set_data(
string: *mut NvdDynamicString,
data: *const c_char,
)Expand description
@brief Sets the actual string inside the given @ref NvdDynamicString.
@param string The @ref NvdDynamicString to modify.
@param data The string to set as the contents of the NvdDynamicString.
@note This will discard any existing data in the string. If you wish to simply append @ref data to the string, see @ref nvd_append_to_string
@since v0.10.0
@ingroup String