pub type NvdNotification = _NvdNotification;Expand description
@brief The base notification type used by NvDialog.
NvDialog offers since v0.5.0 support for basic notifications that
add an extra cross-platform solution. The notification API is cross-platform
and should reduce the required setup to send a simple notification. On GNU/Linux,
libnotify is OPTIONALLY used at runtime to send notifications, meaning it’s not a
hard dependency. In addition, it can be disabled from being loaded entirely at initialization
by setting the environment variable NVD_NO_NOTIFS to any value (except 0). Note that if you
need to create a notification down the line it will load instances of the library separately,
but only if you insist so.
@ingroup Notification @sa nvd_notification_new @since v0.5.0
Aliased Type
pub struct NvdNotification { /* private fields */ }